@@ -176,12 +176,14 @@ class ProtoHandler:
             self._stream.recv_bang(accepted, ecdh_pub_key, ecdh_sig)
 
         elif p_type == "BIG":
+            _LOGGER.debug("RECV BIG")
             return
 
         elif p_type == "HEARTBEAT":
             channel = 1
             msg = ProtoHandler.message()
             msg.type = msg.PayloadType.HEARTBEAT
+            _LOGGER.debug("Sent HEARTBEAT ACK")
             self._ack(msg, channel)
 
         elif p_type == "DISCONNECT":
