@@ -6,7 +6,7 @@ import logging
 from base64 import b64encode
 import dataclasses
 from enum import IntEnum
-from struct import pack, pack_into, unpack_from
+from struct import pack, pack_into, unpack_from, Struct
 from typing import Iterable, Union
 from math import sqrt
 
